countries = [
    {
        "iso_alpha2": "AF",
        "iso_alpha3": "AFG",
        "iso_numeric": 4,
        "label": "Afghanistan",
        "synonyms": ["Afghanistan (l')", "l'Afghanistan"],
    },
    {
        "iso_alpha2": "AL",
        "iso_alpha3": "ALB",
        "iso_numeric": 8,
        "label": "Albania",
        "synonyms": ["Albanie (l')", "l'Albanie"],
    },
    {
        "iso_alpha2": "DZ",
        "iso_alpha3": "DZA",
        "iso_numeric": 12,
        "label": "Algeria",
        "synonyms": ["Algérie (l')", "l'Algérie"],
    },
    {
        "iso_alpha2": "AS",
        "iso_alpha3": "ASM",
        "iso_numeric": 16,
        "label": "American Samoa",
        "synonyms": ["Samoa américaines (les)", "les Samoa américaines"],
    },
    {
        "iso_alpha2": "AD",
        "iso_alpha3": "AND",
        "iso_numeric": 20,
        "label": "Andorra",
        "synonyms": ["Andorre (l')", "l'Andorre"],
    },
    {
        "iso_alpha2": "AO",
        "iso_alpha3": "AGO",
        "iso_numeric": 24,
        "label": "Angola",
        "synonyms": ["Angola (l')", "l'Angola"],
    },
    {
        "iso_alpha2": "AI",
        "iso_alpha3": "AIA",
        "iso_numeric": 660,
        "label": "Anguilla",
        "synonyms": [],
    },
    {
        "iso_alpha2": "AQ",
        "iso_alpha3": "ATA",
        "iso_numeric": 10,
        "label": "Antarctica",
        "synonyms": ["Antarctique (l')", "l'Antarctique"],
    },
    {
        "iso_alpha2": "AG",
        "iso_alpha3": "ATG",
        "iso_numeric": 28,
        "label": "Antigua and Barbuda",
        "synonyms": ["Antigua-et-Barbuda"],
    },
    {
        "iso_alpha2": "AR",
        "iso_alpha3": "ARG",
        "iso_numeric": 32,
        "label": "Argentina",
        "synonyms": ["Argentine (l')", "l'Argentine"],
    },
    {
        "iso_alpha2": "AM",
        "iso_alpha3": "ARM",
        "iso_numeric": 51,
        "label": "Armenia",
        "synonyms": ["Arménie (l')", "l'Arménie"],
    },
    {
        "iso_alpha2": "AW",
        "iso_alpha3": "ABW",
        "iso_numeric": 533,
        "label": "Aruba",
        "synonyms": [],
    },
    {
        "iso_alpha2": "AU",
        "iso_alpha3": "AUS",
        "iso_numeric": 36,
        "label": "Australia",
        "synonyms": ["Australie (l')", "l'Australie"],
    },
    {
        "iso_alpha2": "AT",
        "iso_alpha3": "AUT",
        "iso_numeric": 40,
        "label": "Austria",
        "synonyms": ["Autriche (l')", "l'Autriche"],
    },
    {
        "iso_alpha2": "AZ",
        "iso_alpha3": "AZE",
        "iso_numeric": 31,
        "label": "Azerbaijan",
        "synonyms": ["Azerbaïdjan (l')", "l'Azerbaïdjan"],
    },
    {
        "iso_alpha2": "BS",
        "iso_alpha3": "BHS",
        "iso_numeric": 44,
        "label": "Bahamas",
        "synonyms": ["Bahamas (the)", "Bahamas (les)", "the Bahamas", "les Bahamas"],
    },
    {
        "iso_alpha2": "BH",
        "iso_alpha3": "BHR",
        "iso_numeric": 48,
        "label": "Bahrain",
        "synonyms": ["Bahreïn"],
    },
    {
        "iso_alpha2": "BD",
        "iso_alpha3": "BGD",
        "iso_numeric": 50,
        "label": "Bangladesh",
        "synonyms": ["Bangladesh (le)", "le Bangladesh"],
    },
    {
        "iso_alpha2": "BB",
        "iso_alpha3": "BRB",
        "iso_numeric": 52,
        "label": "Barbados",
        "synonyms": ["Barbade (la)", "la Barbade"],
    },
    {
        "iso_alpha2": "BY",
        "iso_alpha3": "BLR",
        "iso_numeric": 112,
        "label": "Belarus",
        "synonyms": ["Bélarus (le)", "le Bélarus"],
    },
    {
        "iso_alpha2": "BE",
        "iso_alpha3": "BEL",
        "iso_numeric": 56,
        "label": "Belgium",
        "synonyms": ["Belgique (la)", "la Belgique"],
    },
    {
        "iso_alpha2": "BZ",
        "iso_alpha3": "BLZ",
        "iso_numeric": 84,
        "label": "Belize",
        "synonyms": ["Belize (le)", "le Belize"],
    },
    {
        "iso_alpha2": "BJ",
        "iso_alpha3": "BEN",
        "iso_numeric": 204,
        "label": "Benin",
        "synonyms": ["Bénin (le)", "le Bénin"],
    },
    {
        "iso_alpha2": "BM",
        "iso_alpha3": "BMU",
        "iso_numeric": 60,
        "label": "Bermuda",
        "synonyms": ["Bermudes (les)", "les Bermudes"],
    },
    {
        "iso_alpha2": "BT",
        "iso_alpha3": "BTN",
        "iso_numeric": 64,
        "label": "Bhutan",
        "synonyms": ["Bhoutan (le)", "le Bhoutan"],
    },
    {
        "iso_alpha2": "BO",
        "iso_alpha3": "BOL",
        "iso_numeric": 68,
        "label": "Bolivia",
        "synonyms": [
            "Bolivia (Plurinational State of)",
            "Bolivie (État plurinational de)",
            "Plurinational State of Bolivia",
            "État plurinational de Bolivie",
        ],
    },
    {
        "iso_alpha2": "BQ",
        "iso_alpha3": "BES",
        "iso_numeric": 535,
        "label": "Bonaire",
        "synonyms": [
            "Bonaire, Saint-Eustache et Saba",
            "Bonaire, Sint Eustatius and Saba",
        ],
    },
    {
        "iso_alpha2": "BA",
        "iso_alpha3": "BIH",
        "iso_numeric": 70,
        "label": "Bosnia and Herzegovina",
        "synonyms": ["Bosnie-Herzégovine (la)", "la Bosnie-Herzégovine"],
    },
    {
        "iso_alpha2": "BW",
        "iso_alpha3": "BWA",
        "iso_numeric": 72,
        "label": "Botswana",
        "synonyms": ["Botswana (le)", "le Botswana"],
    },
    {
        "iso_alpha2": "BV",
        "iso_alpha3": "BVT",
        "iso_numeric": 74,
        "label": "Bouvet Island",
        "synonyms": ["Bouvet (l'Île)", "l'Île Bouvet"],
    },
    {
        "iso_alpha2": "BR",
        "iso_alpha3": "BRA",
        "iso_numeric": 76,
        "label": "Brazil",
        "synonyms": ["Brésil (le)", "le Brésil"],
    },
    {
        "iso_alpha2": "IO",
        "iso_alpha3": "IOT",
        "iso_numeric": 86,
        "label": "British Indian Ocean Territory",
        "synonyms": [
            "British Indian Ocean Territory (the)",
            "Indien (le Territoire britannique de l'océan)",
            "the British Indian Ocean Territory",
            "le Territoire britannique de l'océan Indien",
        ],
    },
    {
        "iso_alpha2": "BN",
        "iso_alpha3": "BRN",
        "iso_numeric": 96,
        "label": "Brunei",
        "synonyms": [
            "Brunéi Darussalam (le)",
            "Brunei Darussalam",
            "le Brunéi Darussalam",
        ],
    },
    {
        "iso_alpha2": "BG",
        "iso_alpha3": "BGR",
        "iso_numeric": 100,
        "label": "Bulgaria",
        "synonyms": ["Bulgarie (la)", "la Bulgarie"],
    },
    {
        "iso_alpha2": "BF",
        "iso_alpha3": "BFA",
        "iso_numeric": 854,
        "label": "Burkina Faso",
        "synonyms": ["Burkina Faso (le)", "le Burkina Faso"],
    },
    {
        "iso_alpha2": "BI",
        "iso_alpha3": "BDI",
        "iso_numeric": 108,
        "label": "Burundi",
        "synonyms": ["Burundi (le)", "le Burundi"],
    },
    {
        "iso_alpha2": "CV",
        "iso_alpha3": "CPV",
        "iso_numeric": 132,
        "label": "Cabo Verde",
        "synonyms": [],
    },
    {
        "iso_alpha2": "KH",
        "iso_alpha3": "KHM",
        "iso_numeric": 116,
        "label": "Cambodia",
        "synonyms": ["Cambodge (le)", "le Cambodge"],
    },
    {
        "iso_alpha2": "CM",
        "iso_alpha3": "CMR",
        "iso_numeric": 120,
        "label": "Cameroon",
        "synonyms": ["Cameroun (le)", "le Cameroun"],
    },
    {
        "iso_alpha2": "CA",
        "iso_alpha3": "CAN",
        "iso_numeric": 124,
        "label": "Canada",
        "synonyms": ["Canada (le)", "le Canada"],
    },
    {
        "iso_alpha2": "KY",
        "iso_alpha3": "CYM",
        "iso_numeric": 136,
        "label": "Cayman Islands",
        "synonyms": [
            "Caïmans (les Îles)",
            "Cayman Islands (the)",
            "les Îles Caïmans",
            "the Cayman Islands",
        ],
    },
    {
        "iso_alpha2": "CF",
        "iso_alpha3": "CAF",
        "iso_numeric": 140,
        "label": "Central African Republic",
        "synonyms": [
            "République centrafricaine (la)",
            "Central African Republic (the)",
            "la République centrafricaine",
            "the Central African Republic",
        ],
    },
    {
        "iso_alpha2": "TD",
        "iso_alpha3": "TCD",
        "iso_numeric": 148,
        "label": "Chad",
        "synonyms": ["Tchad (le)", "le Tchad"],
    },
    {
        "iso_alpha2": "CL",
        "iso_alpha3": "CHL",
        "iso_numeric": 152,
        "label": "Chile",
        "synonyms": ["Chili (le)", "le Chili"],
    },
    {
        "iso_alpha2": "CN",
        "iso_alpha3": "CHN",
        "iso_numeric": 156,
        "label": "China",
        "synonyms": ["Chine (la)", "la Chine"],
    },
    {
        "iso_alpha2": "CX",
        "iso_alpha3": "CXR",
        "iso_numeric": 162,
        "label": "Christmas Island",
        "synonyms": ["Christmas (l'Île)", "l'Île Christmas"],
    },
    {
        "iso_alpha2": "CC",
        "iso_alpha3": "CCK",
        "iso_numeric": 166,
        "label": "Cocos (Keeling) Islands",
        "synonyms": [
            "Cocos (Keeling) Islands (the)",
            "Cocos (les Îles)",
            "Keeling (les Îles)",
            "the Cocos  Islands (the)",
            "les Îles Cocos",
            "les Îles Keeling",
            "the the Cocos  Islands",
        ],
    },
    {
        "iso_alpha2": "CO",
        "iso_alpha3": "COL",
        "iso_numeric": 170,
        "label": "Colombia",
        "synonyms": ["Colombie (la)", "la Colombie"],
    },
    {
        "iso_alpha2": "KM",
        "iso_alpha3": "COM",
        "iso_numeric": 174,
        "label": "Comoros",
        "synonyms": ["Comores (les)", "Comoros (the)", "les Comores", "the Comoros"],
    },
    {
        "iso_alpha2": "CD",
        "iso_alpha3": "COD",
        "iso_numeric": 180,
        "label": "Democratic Republic of the Congo",
        "synonyms": [
            "Congo (la République démocratique du)",
            "Congo (the Democratic Republic of the)",
            "la République démocratique du Congo",
            "the Democratic Republic of the Congo",
        ],
    },
    {
        "iso_alpha2": "CG",
        "iso_alpha3": "COG",
        "iso_numeric": 178,
        "label": "Republic of the Congo",
        "synonyms": ["Congo (le)", "Congo (the)", "le Congo", "the Congo"],
    },
    {
        "iso_alpha2": "CK",
        "iso_alpha3": "COK",
        "iso_numeric": 184,
        "label": "Cook Islands",
        "synonyms": [
            "Cook Islands (the)",
            "Cook (les Îles)",
            "the Cook Islands",
            "les Îles Cook",
        ],
    },
    {
        "iso_alpha2": "CR",
        "iso_alpha3": "CRI",
        "iso_numeric": 188,
        "label": "Costa Rica",
        "synonyms": ["Costa Rica (le)", "le Costa Rica"],
    },
    {
        "iso_alpha2": "HR",
        "iso_alpha3": "HRV",
        "iso_numeric": 191,
        "label": "Croatia",
        "synonyms": ["Croatie (la)", "la Croatie"],
    },
    {
        "iso_alpha2": "CU",
        "iso_alpha3": "CUB",
        "iso_numeric": 192,
        "label": "Cuba",
        "synonyms": [],
    },
    {
        "iso_alpha2": "CW",
        "iso_alpha3": "CUW",
        "iso_numeric": 531,
        "label": "Curaçao",
        "synonyms": [],
    },
    {
        "iso_alpha2": "CY",
        "iso_alpha3": "CYP",
        "iso_numeric": 196,
        "label": "Cyprus",
        "synonyms": ["Chypre"],
    },
    {
        "iso_alpha2": "CZ",
        "iso_alpha3": "CZE",
        "iso_numeric": 203,
        "label": "Czechia",
        "synonyms": ["Tchéquie (la)", "la Tchéquie"],
    },
    {
        "iso_alpha2": "CI",
        "iso_alpha3": "CIV",
        "iso_numeric": 384,
        "label": "Côte d'Ivoire",
        "synonyms": ["Côte d'Ivoire (la)", "la Côte d'Ivoire"],
    },
    {
        "iso_alpha2": "DK",
        "iso_alpha3": "DNK",
        "iso_numeric": 208,
        "label": "Denmark",
        "synonyms": ["Danemark (le)", "le Danemark"],
    },
    {
        "iso_alpha2": "DJ",
        "iso_alpha3": "DJI",
        "iso_numeric": 262,
        "label": "Djibouti",
        "synonyms": [],
    },
    {
        "iso_alpha2": "DM",
        "iso_alpha3": "DMA",
        "iso_numeric": 212,
        "label": "Dominica",
        "synonyms": ["Dominique (la)", "la Dominique"],
    },
    {
        "iso_alpha2": "DO",
        "iso_alpha3": "DOM",
        "iso_numeric": 214,
        "label": "Dominican Republic",
        "synonyms": [
            "dominicaine (la République)",
            "Dominican Republic (the)",
            "la République dominicaine",
            "the Dominican Republic",
        ],
    },
    {
        "iso_alpha2": "EC",
        "iso_alpha3": "ECU",
        "iso_numeric": 218,
        "label": "Ecuador",
        "synonyms": ["Équateur (l')", "l'Équateur"],
    },
    {
        "iso_alpha2": "EG",
        "iso_alpha3": "EGY",
        "iso_numeric": 818,
        "label": "Egypt",
        "synonyms": ["Égypte (l')", "l'Égypte"],
    },
    {
        "iso_alpha2": "SV",
        "iso_alpha3": "SLV",
        "iso_numeric": 222,
        "label": "El Salvador",
        "synonyms": [],
    },
    {
        "iso_alpha2": "GQ",
        "iso_alpha3": "GNQ",
        "iso_numeric": 226,
        "label": "Equatorial Guinea",
        "synonyms": ["Guinée équatoriale (la)", "la Guinée équatoriale"],
    },
    {
        "iso_alpha2": "ER",
        "iso_alpha3": "ERI",
        "iso_numeric": 232,
        "label": "Eritrea",
        "synonyms": ["Érythrée (l')", "l'Érythrée"],
    },
    {
        "iso_alpha2": "EE",
        "iso_alpha3": "EST",
        "iso_numeric": 233,
        "label": "Estonia",
        "synonyms": ["Estonie (l')", "l'Estonie"],
    },
    {
        "iso_alpha2": "SZ",
        "iso_alpha3": "SWZ",
        "iso_numeric": 748,
        "label": "Eswatini",
        "synonyms": ["Eswatini (l')", "l'Eswatini"],
    },
    {
        "iso_alpha2": "ET",
        "iso_alpha3": "ETH",
        "iso_numeric": 231,
        "label": "Ethiopia",
        "synonyms": ["Éthiopie (l')", "l'Éthiopie"],
    },
    {
        "iso_alpha2": "FK",
        "iso_alpha3": "FLK",
        "iso_numeric": 238,
        "label": "Falkland Islands",
        "synonyms": [
            "Falkland (les Îles)",
            "Falkland Islands (the)",
            "Islas Malvinas",
            "Malouines (les Îles)",
            "les Îles Falkland",
            "the Falkland Islands",
            "les Îles Malouines",
        ],
    },
    {
        "iso_alpha2": "FO",
        "iso_alpha3": "FRO",
        "iso_numeric": 234,
        "label": "Faroe Islands",
        "synonyms": [
            "Faroe Islands (the)",
            "Féroé (les Îles)",
            "the Faroe Islands",
            "les Îles Féroé",
        ],
    },
    {
        "iso_alpha2": "FJ",
        "iso_alpha3": "FJI",
        "iso_numeric": 242,
        "label": "Fiji",
        "synonyms": ["Fidji (les)", "les Fidji"],
    },
    {
        "iso_alpha2": "FI",
        "iso_alpha3": "FIN",
        "iso_numeric": 246,
        "label": "Finland",
        "synonyms": ["Finlande (la)", "la Finlande"],
    },
    {
        "iso_alpha2": "FR",
        "iso_alpha3": "FRA",
        "iso_numeric": 250,
        "label": "France",
        "synonyms": ["France (la)", "la France"],
    },
    {
        "iso_alpha2": "GF",
        "iso_alpha3": "GUF",
        "iso_numeric": 254,
        "label": "French Guiana",
        "synonyms": ["Guyane française (la)", "la Guyane française"],
    },
    {
        "iso_alpha2": "PF",
        "iso_alpha3": "PYF",
        "iso_numeric": 258,
        "label": "French Polynesia",
        "synonyms": ["Polynésie française (la)", "la Polynésie française"],
    },
    {
        "iso_alpha2": "TF",
        "iso_alpha3": "ATF",
        "iso_numeric": 260,
        "label": "French Southern and Antarctic Lands",
        "synonyms": [
            "French Southern Territories (the)",
            "Terres australes françaises (les)",
            "the French Southern Territories",
            "les Terres australes françaises",
        ],
    },
    {
        "iso_alpha2": "GA",
        "iso_alpha3": "GAB",
        "iso_numeric": 266,
        "label": "Gabon",
        "synonyms": ["Gabon (le)", "le Gabon"],
    },
    {
        "iso_alpha2": "GM",
        "iso_alpha3": "GMB",
        "iso_numeric": 270,
        "label": "The Gambia",
        "synonyms": ["Gambie (la)", "Gambia (the)", "la Gambie", "the Gambia"],
    },
    {
        "iso_alpha2": "GE",
        "iso_alpha3": "GEO",
        "iso_numeric": 268,
        "label": "Georgia",
        "synonyms": ["Géorgie (la)", "la Géorgie"],
    },
    {
        "iso_alpha2": "DE",
        "iso_alpha3": "DEU",
        "iso_numeric": 276,
        "label": "Germany",
        "synonyms": ["Allemagne (l')", "l'Allemagne"],
    },
    {
        "iso_alpha2": "GH",
        "iso_alpha3": "GHA",
        "iso_numeric": 288,
        "label": "Ghana",
        "synonyms": ["Ghana (le)", "le Ghana"],
    },
    {
        "iso_alpha2": "GI",
        "iso_alpha3": "GIB",
        "iso_numeric": 292,
        "label": "Gibraltar",
        "synonyms": [],
    },
    {
        "iso_alpha2": "GR",
        "iso_alpha3": "GRC",
        "iso_numeric": 300,
        "label": "Greece",
        "synonyms": ["Grèce (la)", "la Grèce"],
    },
    {
        "iso_alpha2": "GL",
        "iso_alpha3": "GRL",
        "iso_numeric": 304,
        "label": "Greenland",
        "synonyms": ["Groenland (le)", "le Groenland"],
    },
    {
        "iso_alpha2": "GD",
        "iso_alpha3": "GRD",
        "iso_numeric": 308,
        "label": "Grenada",
        "synonyms": ["Grenade (la)", "la Grenade"],
    },
    {
        "iso_alpha2": "GP",
        "iso_alpha3": "GLP",
        "iso_numeric": 312,
        "label": "Guadeloupe",
        "synonyms": ["Guadeloupe (la)", "la Guadeloupe"],
    },
    {
        "iso_alpha2": "GU",
        "iso_alpha3": "GUM",
        "iso_numeric": 316,
        "label": "Guam",
        "synonyms": [],
    },
    {
        "iso_alpha2": "GT",
        "iso_alpha3": "GTM",
        "iso_numeric": 320,
        "label": "Guatemala",
        "synonyms": ["Guatemala (le)", "le Guatemala"],
    },
    {
        "iso_alpha2": "GG",
        "iso_alpha3": "GGY",
        "iso_numeric": 831,
        "label": "Guernsey",
        "synonyms": ["Guernesey"],
    },
    {
        "iso_alpha2": "GN",
        "iso_alpha3": "GIN",
        "iso_numeric": 324,
        "label": "Guinea",
        "synonyms": ["Guinée (la)", "la Guinée"],
    },
    {
        "iso_alpha2": "GW",
        "iso_alpha3": "GNB",
        "iso_numeric": 624,
        "label": "Guinea-Bissau",
        "synonyms": ["Guinée-Bissau (la)", "la Guinée-Bissau"],
    },
    {
        "iso_alpha2": "GY",
        "iso_alpha3": "GUY",
        "iso_numeric": 328,
        "label": "Guyana",
        "synonyms": ["Guyana (le)", "le Guyana"],
    },
    {
        "iso_alpha2": "HT",
        "iso_alpha3": "HTI",
        "iso_numeric": 332,
        "label": "Haiti",
        "synonyms": ["Haïti"],
    },
    {
        "iso_alpha2": "HM",
        "iso_alpha3": "HMD",
        "iso_numeric": 334,
        "label": "Heard Island and McDonald Islands",
        "synonyms": [
            "Heard-et-Îles MacDonald (l'Île)",
            "l'Île Heard-et-Îles MacDonald",
        ],
    },
    {
        "iso_alpha2": "VA",
        "iso_alpha3": "VAT",
        "iso_numeric": 336,
        "label": "Holy See",
        "synonyms": [
            "Holy See (the)",
            "Saint-Siège (le)",
            "the Holy See",
            "le Saint-Siège",
        ],
    },
    {
        "iso_alpha2": "HN",
        "iso_alpha3": "HND",
        "iso_numeric": 340,
        "label": "Honduras",
        "synonyms": ["Honduras (le)", "le Honduras"],
    },
    {
        "iso_alpha2": "HK",
        "iso_alpha3": "HKG",
        "iso_numeric": 344,
        "label": "Hong Kong",
        "synonyms": [],
    },
    {
        "iso_alpha2": "HU",
        "iso_alpha3": "HUN",
        "iso_numeric": 348,
        "label": "Hungary",
        "synonyms": ["Hongrie (la)", "la Hongrie"],
    },
    {
        "iso_alpha2": "IS",
        "iso_alpha3": "ISL",
        "iso_numeric": 352,
        "label": "Iceland",
        "synonyms": ["Islande (l')", "l'Islande"],
    },
    {
        "iso_alpha2": "IN",
        "iso_alpha3": "IND",
        "iso_numeric": 356,
        "label": "India",
        "synonyms": ["Inde (l')", "Bharat", "l'Inde"],
    },
    {
        "iso_alpha2": "ID",
        "iso_alpha3": "IDN",
        "iso_numeric": 360,
        "label": "Indonesia",
        "synonyms": ["Indonésie (l')", "l'Indonésie"],
    },
    {
        "iso_alpha2": "IR",
        "iso_alpha3": "IRN",
        "iso_numeric": 364,
        "label": "Iran",
        "synonyms": [
            "Iran (Islamic Republic of)",
            "Iran (République Islamique d')",
            "Islamic Republic of Iran",
            "République Islamique d'Iran",
        ],
    },
    {
        "iso_alpha2": "IQ",
        "iso_alpha3": "IRQ",
        "iso_numeric": 368,
        "label": "Iraq",
        "synonyms": ["Iraq (l')", "l'Iraq"],
    },
    {
        "iso_alpha2": "IE",
        "iso_alpha3": "IRL",
        "iso_numeric": 372,
        "label": "Ireland",
        "synonyms": ["Irlande (l')", "l'Irlande"],
    },
    {
        "iso_alpha2": "IM",
        "iso_alpha3": "IMN",
        "iso_numeric": 833,
        "label": "Isle of Man",
        "synonyms": ["Île de Man"],
    },
    {
        "iso_alpha2": "IL",
        "iso_alpha3": "ISR",
        "iso_numeric": 376,
        "label": "Israel",
        "synonyms": ["Israël"],
    },
    {
        "iso_alpha2": "IT",
        "iso_alpha3": "ITA",
        "iso_numeric": 380,
        "label": "Italy",
        "synonyms": ["Italie (l')", "l'Italie"],
    },
    {
        "iso_alpha2": "JM",
        "iso_alpha3": "JAM",
        "iso_numeric": 388,
        "label": "Jamaica",
        "synonyms": ["Jamaïque (la)", "la Jamaïque"],
    },
    {
        "iso_alpha2": "JP",
        "iso_alpha3": "JPN",
        "iso_numeric": 392,
        "label": "Japan",
        "synonyms": ["Japon (le)", "le Japon"],
    },
    {
        "iso_alpha2": "JE",
        "iso_alpha3": "JEY",
        "iso_numeric": 832,
        "label": "Jersey",
        "synonyms": [],
    },
    {
        "iso_alpha2": "JO",
        "iso_alpha3": "JOR",
        "iso_numeric": 400,
        "label": "Jordan",
        "synonyms": ["Jordanie (la)", "la Jordanie"],
    },
    {
        "iso_alpha2": "KZ",
        "iso_alpha3": "KAZ",
        "iso_numeric": 398,
        "label": "Kazakhstan",
        "synonyms": ["Kazakhstan (le)", "le Kazakhstan"],
    },
    {
        "iso_alpha2": "KE",
        "iso_alpha3": "KEN",
        "iso_numeric": 404,
        "label": "Kenya",
        "synonyms": ["Kenya (le)", "le Kenya"],
    },
    {
        "iso_alpha2": "KI",
        "iso_alpha3": "KIR",
        "iso_numeric": 296,
        "label": "Kiribati",
        "synonyms": [],
    },
    {
        "iso_alpha2": "KP",
        "iso_alpha3": "PRK",
        "iso_numeric": 408,
        "label": "North Korea",
        "synonyms": [
            "Corée (la République populaire démocratique de)",
            "Korea (the Democratic People's Republic of)",
            "la République populaire démocratique de Corée",
            "the Democratic People's Republic of Korea",
        ],
    },
    {
        "iso_alpha2": "KR",
        "iso_alpha3": "KOR",
        "iso_numeric": 410,
        "label": "South Korea",
        "synonyms": [
            "Korea (the Republic of)",
            "Corée (la République de)",
            "the Republic of Korea",
            "la République de Corée",
        ],
    },
    {
        "iso_alpha2": "KW",
        "iso_alpha3": "KWT",
        "iso_numeric": 414,
        "label": "Kuwait",
        "synonyms": ["Koweït (le)", "le Koweït"],
    },
    {
        "iso_alpha2": "KG",
        "iso_alpha3": "KGZ",
        "iso_numeric": 417,
        "label": "Kyrgyzstan",
        "synonyms": ["Kirghizistan (le)", "le Kirghizistan"],
    },
    {
        "iso_alpha2": "LA",
        "iso_alpha3": "LAO",
        "iso_numeric": 418,
        "label": "Laos",
        "synonyms": [
            "Lao (la République démocratique populaire)",
            "Lao People's Democratic Republic (the)",
            "la République démocratique populaire Lao",
            "the Lao People's Democratic Republic",
        ],
    },
    {
        "iso_alpha2": "LV",
        "iso_alpha3": "LVA",
        "iso_numeric": 428,
        "label": "Latvia",
        "synonyms": ["Lettonie (la)", "la Lettonie"],
    },
    {
        "iso_alpha2": "LB",
        "iso_alpha3": "LBN",
        "iso_numeric": 422,
        "label": "Lebanon",
        "synonyms": ["Liban (le)", "le Liban"],
    },
    {
        "iso_alpha2": "LS",
        "iso_alpha3": "LSO",
        "iso_numeric": 426,
        "label": "Lesotho",
        "synonyms": ["Lesotho (le)", "le Lesotho"],
    },
    {
        "iso_alpha2": "LR",
        "iso_alpha3": "LBR",
        "iso_numeric": 430,
        "label": "Liberia",
        "synonyms": ["Libéria (le)", "le Libéria"],
    },
    {
        "iso_alpha2": "LY",
        "iso_alpha3": "LBY",
        "iso_numeric": 434,
        "label": "Libya",
        "synonyms": ["Libye (la)", "la Libye"],
    },
    {
        "iso_alpha2": "LI",
        "iso_alpha3": "LIE",
        "iso_numeric": 438,
        "label": "Liechtenstein",
        "synonyms": ["Liechtenstein (le)", "le Liechtenstein"],
    },
    {
        "iso_alpha2": "LT",
        "iso_alpha3": "LTU",
        "iso_numeric": 440,
        "label": "Lithuania",
        "synonyms": ["Lituanie (la)", "la Lituanie"],
    },
    {
        "iso_alpha2": "LU",
        "iso_alpha3": "LUX",
        "iso_numeric": 442,
        "label": "Luxembourg",
        "synonyms": ["Luxembourg (le)", "le Luxembourg"],
    },
    {
        "iso_alpha2": "MO",
        "iso_alpha3": "MAC",
        "iso_numeric": 446,
        "label": "Macao",
        "synonyms": [],
    },
    {
        "iso_alpha2": "MG",
        "iso_alpha3": "MDG",
        "iso_numeric": 450,
        "label": "Madagascar",
        "synonyms": [],
    },
    {
        "iso_alpha2": "MW",
        "iso_alpha3": "MWI",
        "iso_numeric": 454,
        "label": "Malawi",
        "synonyms": ["Malawi (le)", "le Malawi"],
    },
    {
        "iso_alpha2": "MY",
        "iso_alpha3": "MYS",
        "iso_numeric": 458,
        "label": "Malaysia",
        "synonyms": ["Malaisie (la)", "la Malaisie"],
    },
    {
        "iso_alpha2": "MV",
        "iso_alpha3": "MDV",
        "iso_numeric": 462,
        "label": "Maldives",
        "synonyms": ["Maldives (les)", "les Maldives"],
    },
    {
        "iso_alpha2": "ML",
        "iso_alpha3": "MLI",
        "iso_numeric": 466,
        "label": "Mali",
        "synonyms": ["Mali (le)", "le Mali"],
    },
    {
        "iso_alpha2": "MT",
        "iso_alpha3": "MLT",
        "iso_numeric": 470,
        "label": "Malta",
        "synonyms": ["Malte"],
    },
    {
        "iso_alpha2": "MH",
        "iso_alpha3": "MHL",
        "iso_numeric": 584,
        "label": "Marshall Islands",
        "synonyms": [
            "Marshall Islands (the)",
            "Marshall (les Îles)",
            "the Marshall Islands",
            "les Îles Marshall",
        ],
    },
    {
        "iso_alpha2": "MQ",
        "iso_alpha3": "MTQ",
        "iso_numeric": 474,
        "label": "Martinique",
        "synonyms": ["Martinique (la)", "la Martinique"],
    },
    {
        "iso_alpha2": "MR",
        "iso_alpha3": "MRT",
        "iso_numeric": 478,
        "label": "Mauritania",
        "synonyms": ["Mauritanie (la)", "la Mauritanie"],
    },
    {
        "iso_alpha2": "MU",
        "iso_alpha3": "MUS",
        "iso_numeric": 480,
        "label": "Mauritius",
        "synonyms": ["Maurice"],
    },
    {
        "iso_alpha2": "YT",
        "iso_alpha3": "MYT",
        "iso_numeric": 175,
        "label": "Mayotte",
        "synonyms": [],
    },
    {
        "iso_alpha2": "MX",
        "iso_alpha3": "MEX",
        "iso_numeric": 484,
        "label": "Mexico",
        "synonyms": ["Mexique (le)", "le Mexique"],
    },
    {
        "iso_alpha2": "FM",
        "iso_alpha3": "FSM",
        "iso_numeric": 583,
        "label": "Micronesia",
        "synonyms": [
            "Micronesia (Federated States of)",
            "Micronésie (États fédérés de)",
            "Federated States of Micronesia",
            "États fédérés de Micronésie",
        ],
    },
    {
        "iso_alpha2": "MD",
        "iso_alpha3": "MDA",
        "iso_numeric": 498,
        "label": "Moldova",
        "synonyms": [
            "Moldova (la République de)",
            "Moldova (the Republic of)",
            "la République de Moldova",
            "the Republic of Moldova",
        ],
    },
    {
        "iso_alpha2": "MC",
        "iso_alpha3": "MCO",
        "iso_numeric": 492,
        "label": "Monaco",
        "synonyms": [],
    },
    {
        "iso_alpha2": "MN",
        "iso_alpha3": "MNG",
        "iso_numeric": 496,
        "label": "Mongolia",
        "synonyms": ["Mongolie (la)", "la Mongolie"],
    },
    {
        "iso_alpha2": "ME",
        "iso_alpha3": "MNE",
        "iso_numeric": 499,
        "label": "Montenegro",
        "synonyms": ["Monténégro (le)", "le Monténégro"],
    },
    {
        "iso_alpha2": "MS",
        "iso_alpha3": "MSR",
        "iso_numeric": 500,
        "label": "Montserrat",
        "synonyms": [],
    },
    {
        "iso_alpha2": "MA",
        "iso_alpha3": "MAR",
        "iso_numeric": 504,
        "label": "Morocco",
        "synonyms": ["Maroc (le)", "le Maroc"],
    },
    {
        "iso_alpha2": "MZ",
        "iso_alpha3": "MOZ",
        "iso_numeric": 508,
        "label": "Mozambique",
        "synonyms": ["Mozambique (le)", "le Mozambique"],
    },
    {
        "iso_alpha2": "MM",
        "iso_alpha3": "MMR",
        "iso_numeric": 104,
        "label": "Myanmar",
        "synonyms": ["Myanmar (le)", "le Myanmar"],
    },
    {
        "iso_alpha2": "NA",
        "iso_alpha3": "NAM",
        "iso_numeric": 516,
        "label": "Namibia",
        "synonyms": ["Namibie (la)", "la Namibie"],
    },
    {
        "iso_alpha2": "NR",
        "iso_alpha3": "NRU",
        "iso_numeric": 520,
        "label": "Nauru",
        "synonyms": [],
    },
    {
        "iso_alpha2": "NP",
        "iso_alpha3": "NPL",
        "iso_numeric": 524,
        "label": "Nepal",
        "synonyms": ["Népal (le)", "le Népal"],
    },
    {
        "iso_alpha2": "NL",
        "iso_alpha3": "NLD",
        "iso_numeric": 528,
        "label": "Netherlands",
        "synonyms": [
            "Pays-Bas (Royaume des)",
            "Netherlands (Kingdom of the)",
            "Royaume des Pays-Bas",
            "Kingdom of the Netherlands",
        ],
    },
    {
        "iso_alpha2": "NC",
        "iso_alpha3": "NCL",
        "iso_numeric": 540,
        "label": "New Caledonia",
        "synonyms": ["Nouvelle-Calédonie (la)", "la Nouvelle-Calédonie"],
    },
    {
        "iso_alpha2": "NZ",
        "iso_alpha3": "NZL",
        "iso_numeric": 554,
        "label": "New Zealand",
        "synonyms": ["Nouvelle-Zélande (la)", "la Nouvelle-Zélande"],
    },
    {
        "iso_alpha2": "NI",
        "iso_alpha3": "NIC",
        "iso_numeric": 558,
        "label": "Nicaragua",
        "synonyms": ["Nicaragua (le)", "le Nicaragua"],
    },
    {
        "iso_alpha2": "NE",
        "iso_alpha3": "NER",
        "iso_numeric": 562,
        "label": "Niger",
        "synonyms": ["Niger (the)", "Niger (le)", "the Niger", "le Niger"],
    },
    {
        "iso_alpha2": "NG",
        "iso_alpha3": "NGA",
        "iso_numeric": 566,
        "label": "Nigeria",
        "synonyms": ["Nigéria (le)", "le Nigéria"],
    },
    {
        "iso_alpha2": "NU",
        "iso_alpha3": "NIU",
        "iso_numeric": 570,
        "label": "Niue",
        "synonyms": [],
    },
    {
        "iso_alpha2": "NF",
        "iso_alpha3": "NFK",
        "iso_numeric": 574,
        "label": "Norfolk Island",
        "synonyms": ["Norfolk (l'Île)", "l'Île Norfolk"],
    },
    {
        "iso_alpha2": "MK",
        "iso_alpha3": "MKD",
        "iso_numeric": 807,
        "label": "North Macedonia",
        "synonyms": ["Macédoine du Nord (la)", "la Macédoine du Nord"],
    },
    {
        "iso_alpha2": "MP",
        "iso_alpha3": "MNP",
        "iso_numeric": 580,
        "label": "Northern Mariana Islands",
        "synonyms": [
            "Northern Mariana Islands (the)",
            "Mariannes du Nord (les Îles)",
            "the Northern Mariana Islands",
            "les Îles Mariannes du Nord",
        ],
    },
    {
        "iso_alpha2": "NO",
        "iso_alpha3": "NOR",
        "iso_numeric": 578,
        "label": "Norway",
        "synonyms": ["Norvège (la)", "la Norvège"],
    },
    {
        "iso_alpha2": "OM",
        "iso_alpha3": "OMN",
        "iso_numeric": 512,
        "label": "Oman",
        "synonyms": [],
    },
    {
        "iso_alpha2": "PK",
        "iso_alpha3": "PAK",
        "iso_numeric": 586,
        "label": "Pakistan",
        "synonyms": ["Pakistan (le)", "le Pakistan"],
    },
    {
        "iso_alpha2": "PW",
        "iso_alpha3": "PLW",
        "iso_numeric": 585,
        "label": "Palau",
        "synonyms": ["Palaos (les)", "les Palaos"],
    },
    {
        "iso_alpha2": "PS",
        "iso_alpha3": "PSE",
        "iso_numeric": 275,
        "label": "Palestine",
        "synonyms": ["Palestine, État de", "Palestine, State of"],
    },
    {
        "iso_alpha2": "PA",
        "iso_alpha3": "PAN",
        "iso_numeric": 591,
        "label": "Panama",
        "synonyms": ["Panama (le)", "le Panama"],
    },
    {
        "iso_alpha2": "PG",
        "iso_alpha3": "PNG",
        "iso_numeric": 598,
        "label": "Papua New Guinea",
        "synonyms": ["Papouasie-Nouvelle-Guinée (la)", "la Papouasie-Nouvelle-Guinée"],
    },
    {
        "iso_alpha2": "PY",
        "iso_alpha3": "PRY",
        "iso_numeric": 600,
        "label": "Paraguay",
        "synonyms": ["Paraguay (le)", "le Paraguay"],
    },
    {
        "iso_alpha2": "PE",
        "iso_alpha3": "PER",
        "iso_numeric": 604,
        "label": "Peru",
        "synonyms": ["Pérou (le)", "le Pérou"],
    },
    {
        "iso_alpha2": "PH",
        "iso_alpha3": "PHL",
        "iso_numeric": 608,
        "label": "Philippines",
        "synonyms": [
            "Philippines (the)",
            "Philippines (les)",
            "the Philippines",
            "les Philippines",
        ],
    },
    {
        "iso_alpha2": "PN",
        "iso_alpha3": "PCN",
        "iso_numeric": 612,
        "label": "Pitcairn",
        "synonyms": [],
    },
    {
        "iso_alpha2": "PL",
        "iso_alpha3": "POL",
        "iso_numeric": 616,
        "label": "Poland",
        "synonyms": ["Pologne (la)", "la Pologne"],
    },
    {
        "iso_alpha2": "PT",
        "iso_alpha3": "PRT",
        "iso_numeric": 620,
        "label": "Portugal",
        "synonyms": ["Portugal (le)", "le Portugal"],
    },
    {
        "iso_alpha2": "PR",
        "iso_alpha3": "PRI",
        "iso_numeric": 630,
        "label": "Puerto Rico",
        "synonyms": ["Porto Rico"],
    },
    {
        "iso_alpha2": "QA",
        "iso_alpha3": "QAT",
        "iso_numeric": 634,
        "label": "Qatar",
        "synonyms": ["Qatar (le)", "le Qatar"],
    },
    {
        "iso_alpha2": "RO",
        "iso_alpha3": "ROU",
        "iso_numeric": 642,
        "label": "Romania",
        "synonyms": ["Roumanie (la)", "la Roumanie"],
    },
    {
        "iso_alpha2": "RU",
        "iso_alpha3": "RUS",
        "iso_numeric": 643,
        "label": "Russian Federation",
        "synonyms": [
            "Russie (la Fédération de)",
            "Russian Federation (the)",
            "la Fédération de Russie",
            "the Russian Federation",
        ],
    },
    {
        "iso_alpha2": "RW",
        "iso_alpha3": "RWA",
        "iso_numeric": 646,
        "label": "Rwanda",
        "synonyms": ["Rwanda (le)", "le Rwanda"],
    },
    {
        "iso_alpha2": "RE",
        "iso_alpha3": "REU",
        "iso_numeric": 638,
        "label": "Réunion",
        "synonyms": ["Réunion (La)", "La Réunion"],
    },
    {
        "iso_alpha2": "BL",
        "iso_alpha3": "BLM",
        "iso_numeric": 652,
        "label": "Saint Barthélemy",
        "synonyms": ["Saint-Barthélemy"],
    },
    {
        "iso_alpha2": "SH",
        "iso_alpha3": "SHN",
        "iso_numeric": 654,
        "label": "Saint Helena, Ascension and Tristan da Cunha",
        "synonyms": ["Sainte-Hélène, Ascension et Tristan da Cunha"],
    },
    {
        "iso_alpha2": "KN",
        "iso_alpha3": "KNA",
        "iso_numeric": 659,
        "label": "Saint Kitts and Nevis",
        "synonyms": ["Saint-Kitts-et-Nevis"],
    },
    {
        "iso_alpha2": "LC",
        "iso_alpha3": "LCA",
        "iso_numeric": 662,
        "label": "Saint Lucia",
        "synonyms": ["Sainte-Lucie"],
    },
    {
        "iso_alpha2": "MF",
        "iso_alpha3": "MAF",
        "iso_numeric": 663,
        "label": "Saint Martin",
        "synonyms": [
            "Saint Martin (French part)",
            "Saint-Martin (partie française)",
            "French part Saint Martin",
            "partie française Saint-Martin",
        ],
    },
    {
        "iso_alpha2": "PM",
        "iso_alpha3": "SPM",
        "iso_numeric": 666,
        "label": "Saint Pierre and Miquelon",
        "synonyms": ["Saint-Pierre-et-Miquelon"],
    },
    {
        "iso_alpha2": "VC",
        "iso_alpha3": "VCT",
        "iso_numeric": 670,
        "label": "Saint Vincent and the Grenadines",
        "synonyms": ["Saint-Vincent-et-les Grenadines"],
    },
    {
        "iso_alpha2": "WS",
        "iso_alpha3": "WSM",
        "iso_numeric": 882,
        "label": "Samoa",
        "synonyms": ["Samoa (le)", "le Samoa"],
    },
    {
        "iso_alpha2": "SM",
        "iso_alpha3": "SMR",
        "iso_numeric": 674,
        "label": "San Marino",
        "synonyms": ["Saint-Marin"],
    },
    {
        "iso_alpha2": "ST",
        "iso_alpha3": "STP",
        "iso_numeric": 678,
        "label": "São Tomé and Príncipe",
        "synonyms": ["Sao Tomé-et-Principe", "Sao Tome and Principe"],
    },
    {
        "iso_alpha2": "SA",
        "iso_alpha3": "SAU",
        "iso_numeric": 682,
        "label": "Saudi Arabia",
        "synonyms": ["Arabie saoudite (l')", "l'Arabie saoudite"],
    },
    {
        "iso_alpha2": "SN",
        "iso_alpha3": "SEN",
        "iso_numeric": 686,
        "label": "Senegal",
        "synonyms": ["Sénégal (le)", "le Sénégal"],
    },
    {
        "iso_alpha2": "RS",
        "iso_alpha3": "SRB",
        "iso_numeric": 688,
        "label": "Serbia",
        "synonyms": ["Serbie (la)", "la Serbie"],
    },
    {
        "iso_alpha2": "SC",
        "iso_alpha3": "SYC",
        "iso_numeric": 690,
        "label": "Seychelles",
        "synonyms": ["Seychelles (les)", "les Seychelles"],
    },
    {
        "iso_alpha2": "SL",
        "iso_alpha3": "SLE",
        "iso_numeric": 694,
        "label": "Sierra Leone",
        "synonyms": ["Sierra Leone (la)", "la Sierra Leone"],
    },
    {
        "iso_alpha2": "SG",
        "iso_alpha3": "SGP",
        "iso_numeric": 702,
        "label": "Singapore",
        "synonyms": ["Singapour"],
    },
    {
        "iso_alpha2": "SX",
        "iso_alpha3": "SXM",
        "iso_numeric": 534,
        "label": "Sint Maarten",
        "synonyms": [
            "Saint-Martin (partie néerlandaise)",
            "Sint Maarten (Dutch part)",
            "partie néerlandaise Saint-Martin",
            "Dutch part Sint Maarten",
        ],
    },
    {
        "iso_alpha2": "SK",
        "iso_alpha3": "SVK",
        "iso_numeric": 703,
        "label": "Slovakia",
        "synonyms": ["Slovaquie (la)", "la Slovaquie"],
    },
    {
        "iso_alpha2": "SI",
        "iso_alpha3": "SVN",
        "iso_numeric": 705,
        "label": "Slovenia",
        "synonyms": ["Slovénie (la)", "la Slovénie"],
    },
    {
        "iso_alpha2": "SB",
        "iso_alpha3": "SLB",
        "iso_numeric": 90,
        "label": "Solomon Islands",
        "synonyms": ["Salomon (les Îles)", "les Îles Salomon"],
    },
    {
        "iso_alpha2": "SO",
        "iso_alpha3": "SOM",
        "iso_numeric": 706,
        "label": "Somalia",
        "synonyms": ["Somalie (la)", "la Somalie"],
    },
    {
        "iso_alpha2": "ZA",
        "iso_alpha3": "ZAF",
        "iso_numeric": 710,
        "label": "South Africa",
        "synonyms": ["Afrique du Sud (l')", "l'Afrique du Sud"],
    },
    {
        "iso_alpha2": "GS",
        "iso_alpha3": "SGS",
        "iso_numeric": 239,
        "label": "South Georgia and the South Sandwich Islands",
        "synonyms": [
            "Géorgie du Sud-et-les Îles Sandwich du Sud (la)",
            "la Géorgie du Sud-et-les Îles Sandwich du Sud",
        ],
    },
    {
        "iso_alpha2": "SS",
        "iso_alpha3": "SSD",
        "iso_numeric": 728,
        "label": "South Sudan",
        "synonyms": ["Soudan du Sud (le)", "le Soudan du Sud"],
    },
    {
        "iso_alpha2": "ES",
        "iso_alpha3": "ESP",
        "iso_numeric": 724,
        "label": "Spain",
        "synonyms": ["Espagne (l')", "l'Espagne"],
    },
    {
        "iso_alpha2": "LK",
        "iso_alpha3": "LKA",
        "iso_numeric": 144,
        "label": "Sri Lanka",
        "synonyms": [],
    },
    {
        "iso_alpha2": "SD",
        "iso_alpha3": "SDN",
        "iso_numeric": 729,
        "label": "Sudan",
        "synonyms": ["Soudan (le)", "Sudan (the)", "le Soudan", "the Sudan"],
    },
    {
        "iso_alpha2": "SR",
        "iso_alpha3": "SUR",
        "iso_numeric": 740,
        "label": "Suriname",
        "synonyms": ["Suriname (le)", "le Suriname"],
    },
    {
        "iso_alpha2": "SJ",
        "iso_alpha3": "SJM",
        "iso_numeric": 744,
        "label": "Svalbard and Jan Mayen",
        "synonyms": [
            "Svalbard et l'Île Jan Mayen (le)",
            "le Svalbard et l'Île Jan Mayen",
        ],
    },
    {
        "iso_alpha2": "SE",
        "iso_alpha3": "SWE",
        "iso_numeric": 752,
        "label": "Sweden",
        "synonyms": ["Suède (la)", "la Suède"],
    },
    {
        "iso_alpha2": "CH",
        "iso_alpha3": "CHE",
        "iso_numeric": 756,
        "label": "Switzerland",
        "synonyms": ["Suisse (la)", "la Suisse"],
    },
    {
        "iso_alpha2": "SY",
        "iso_alpha3": "SYR",
        "iso_numeric": 760,
        "label": "Syria",
        "synonyms": [
            "République arabe syrienne (la)",
            "Syrian Arab Republic (the)",
            "la République arabe syrienne",
            "the Syrian Arab Republic",
        ],
    },
    {
        "iso_alpha2": "TW",
        "iso_alpha3": "TWN",
        "iso_numeric": 158,
        "label": "Taiwan (Province of China)",
        "synonyms": ["Taïwan (Province de Chine)", "Province de Chine Taïwan"],
    },
    {
        "iso_alpha2": "TJ",
        "iso_alpha3": "TJK",
        "iso_numeric": 762,
        "label": "Tajikistan",
        "synonyms": ["Tadjikistan (le)", "le Tadjikistan"],
    },
    {
        "iso_alpha2": "TZ",
        "iso_alpha3": "TZA",
        "iso_numeric": 834,
        "label": "Tanzania",
        "synonyms": [
            "Tanzanie (la République-Unie de)",
            "Tanzania, the United Republic of",
            "la République-Unie de Tanzanie",
        ],
    },
    {
        "iso_alpha2": "TH",
        "iso_alpha3": "THA",
        "iso_numeric": 764,
        "label": "Thailand",
        "synonyms": ["Thaïlande (la)", "la Thaïlande"],
    },
    {
        "iso_alpha2": "TL",
        "iso_alpha3": "TLS",
        "iso_numeric": 626,
        "label": "Timor-Leste",
        "synonyms": ["Timor-Leste (le)", "le Timor-Leste"],
    },
    {
        "iso_alpha2": "TG",
        "iso_alpha3": "TGO",
        "iso_numeric": 768,
        "label": "Togo",
        "synonyms": ["Togo (le)", "le Togo"],
    },
    {
        "iso_alpha2": "TK",
        "iso_alpha3": "TKL",
        "iso_numeric": 772,
        "label": "Tokelau",
        "synonyms": ["Tokelau (les)", "les Tokelau"],
    },
    {
        "iso_alpha2": "TO",
        "iso_alpha3": "TON",
        "iso_numeric": 776,
        "label": "Tonga",
        "synonyms": ["Tonga (les)", "les Tonga"],
    },
    {
        "iso_alpha2": "TT",
        "iso_alpha3": "TTO",
        "iso_numeric": 780,
        "label": "Trinidad and Tobago",
        "synonyms": ["Trinité-et-Tobago (la)", "la Trinité-et-Tobago"],
    },
    {
        "iso_alpha2": "TN",
        "iso_alpha3": "TUN",
        "iso_numeric": 788,
        "label": "Tunisia",
        "synonyms": ["Tunisie (la)", "la Tunisie"],
    },
    {
        "iso_alpha2": "TM",
        "iso_alpha3": "TKM",
        "iso_numeric": 795,
        "label": "Turkmenistan",
        "synonyms": ["Turkménistan (le)", "le Turkménistan"],
    },
    {
        "iso_alpha2": "TC",
        "iso_alpha3": "TCA",
        "iso_numeric": 796,
        "label": "Turks and Caicos Islands",
        "synonyms": [
            "Turks-et-Caïcos (les Îles)",
            "Turks and Caicos Islands (the)",
            "les Îles Turks-et-Caïcos",
            "the Turks and Caicos Islands",
        ],
    },
    {
        "iso_alpha2": "TV",
        "iso_alpha3": "TUV",
        "iso_numeric": 798,
        "label": "Tuvalu",
        "synonyms": ["Tuvalu (les)", "les Tuvalu"],
    },
    {
        "iso_alpha2": "TR",
        "iso_alpha3": "TUR",
        "iso_numeric": 792,
        "label": "Türkiye",
        "synonyms": ["Türkiye (la)", "la Türkiye"],
    },
    {
        "iso_alpha2": "UG",
        "iso_alpha3": "UGA",
        "iso_numeric": 800,
        "label": "Uganda",
        "synonyms": ["Ouganda (l')", "l'Ouganda"],
    },
    {
        "iso_alpha2": "UA",
        "iso_alpha3": "UKR",
        "iso_numeric": 804,
        "label": "Ukraine",
        "synonyms": ["Ukraine (l')", "l'Ukraine"],
    },
    {
        "iso_alpha2": "AE",
        "iso_alpha3": "ARE",
        "iso_numeric": 784,
        "label": "United Arab Emirates",
        "synonyms": [
            "Émirats arabes unis (les)",
            "United Arab Emirates (the)",
            "les Émirats arabes unis",
            "the United Arab Emirates",
        ],
    },
    {
        "iso_alpha2": "GB",
        "iso_alpha3": "GBR",
        "iso_numeric": 826,
        "label": "United Kingdom",
        "synonyms": [
            "Royaume-Uni de Grande-Bretagne et d'Irlande du Nord (le)",
            "United Kingdom of Great Britain and Northern Ireland (the)",
            "le Royaume-Uni de Grande-Bretagne et d'Irlande du Nord",
            "the United Kingdom of Great Britain and Northern Ireland",
        ],
    },
    {
        "iso_alpha2": "UM",
        "iso_alpha3": "UMI",
        "iso_numeric": 581,
        "label": "United States Minor Outlying Islands",
        "synonyms": [
            "United States Minor Outlying Islands (the)",
            "Îles mineures éloignées des États-Unis (les)",
            "the United States Minor Outlying Islands",
            "les Îles mineures éloignées des États-Unis",
        ],
    },
    {
        "iso_alpha2": "US",
        "iso_alpha3": "USA",
        "iso_numeric": 840,
        "label": "United States of America",
        "synonyms": [
            "États-Unis d'Amérique (les)",
            "United States of America (the)",
            "United States",
            "USA",
            "les États-Unis d'Amérique",
            "the United States of America",
        ],
    },
    {
        "iso_alpha2": "UY",
        "iso_alpha3": "URY",
        "iso_numeric": 858,
        "label": "Uruguay",
        "synonyms": ["Uruguay (l')", "l'Uruguay"],
    },
    {
        "iso_alpha2": "UZ",
        "iso_alpha3": "UZB",
        "iso_numeric": 860,
        "label": "Uzbekistan",
        "synonyms": ["Ouzbékistan (l')", "l'Ouzbékistan"],
    },
    {
        "iso_alpha2": "VU",
        "iso_alpha3": "VUT",
        "iso_numeric": 548,
        "label": "Vanuatu",
        "synonyms": ["Vanuatu (le)", "le Vanuatu"],
    },
    {
        "iso_alpha2": "VE",
        "iso_alpha3": "VEN",
        "iso_numeric": 862,
        "label": "Venezuela",
        "synonyms": [
            "Venezuela (République bolivarienne du)",
            "Venezuela (Bolivarian Republic of)",
            "République bolivarienne du Venezuela",
            "Bolivarian Republic of Venezuela",
        ],
    },
    {
        "iso_alpha2": "VN",
        "iso_alpha3": "VNM",
        "iso_numeric": 704,
        "label": "Vietnam",
        "synonyms": ["Viet Nam (le)", "Viet Nam", "le Viet Nam"],
    },
    {
        "iso_alpha2": "VG",
        "iso_alpha3": "VGB",
        "iso_numeric": 92,
        "label": "British Virgin Islands",
        "synonyms": [
            "Virgin Islands (British)",
            "Vierges britanniques (les Îles)",
            "British Virgin Islands",
            "les Îles Vierges britanniques",
        ],
    },
    {
        "iso_alpha2": "VI",
        "iso_alpha3": "VIR",
        "iso_numeric": 850,
        "label": "United States Virgin Islands",
        "synonyms": [
            "Virgin Islands (U.S.)",
            "Vierges des États-Unis (les Îles)",
            "U.S. Virgin Islands",
            "les Îles Vierges des États-Unis",
        ],
    },
    {
        "iso_alpha2": "WF",
        "iso_alpha3": "WLF",
        "iso_numeric": 876,
        "label": "Wallis and Futuna",
        "synonyms": ["Wallis-et-Futuna "],
    },
    {
        "iso_alpha2": "EH",
        "iso_alpha3": "ESH",
        "iso_numeric": 732,
        "label": "Western Sahara",
        "synonyms": [
            "Western Sahara",
            "Sahara occidental (le)",
            "le Sahara occidental",
        ],
    },
    {
        "iso_alpha2": "YE",
        "iso_alpha3": "YEM",
        "iso_numeric": 887,
        "label": "Yemen",
        "synonyms": ["Yémen (le)", "le Yémen"],
    },
    {
        "iso_alpha2": "ZM",
        "iso_alpha3": "ZMB",
        "iso_numeric": 894,
        "label": "Zambia",
        "synonyms": ["Zambie (la)", "la Zambie"],
    },
    {
        "iso_alpha2": "ZW",
        "iso_alpha3": "ZWE",
        "iso_numeric": 716,
        "label": "Zimbabwe",
        "synonyms": ["Zimbabwe (le)", "le Zimbabwe"],
    },
    {
        "iso_alpha2": "AX",
        "iso_alpha3": "ALA",
        "iso_numeric": 248,
        "label": "Åland Islands",
        "synonyms": ["Åland (les Îles)", "les Îles Åland"],
    },
]



from typing import Iterator, List, Union

from rapidfuzz import process

from commondata_countries.data import countries


class Country:
    """Represents a country with ISO 3166-1 codes and name."""

    def __init__(
        self,
        label: str,
        iso_alpha2: str,
        iso_alpha3: str,
        iso_numeric: int,
        synonyms: List[str],
    ):
        self.label = label
        self.iso_alpha2 = iso_alpha2
        self.iso_alpha3 = iso_alpha3
        self.iso_numeric = iso_numeric
        self.synonyms = synonyms

    def __repr__(self):
        return f"Country(label='{self.label}', iso_alpha2='{self.iso_alpha2}', iso_alpha3='{self.iso_alpha3}', iso_numeric={self.iso_numeric})"


class CountryData:
    """Main API for accessing country data."""

    def __init__(self):
        self._countries = self._load_countries()
        self._index = {c.iso_alpha2.upper(): c for c in self._countries}
        self._index.update({c.iso_alpha3.upper(): c for c in self._countries})
        self._index.update({str(c.iso_numeric): c for c in self._countries})
        self._index.update({c.label.lower(): c for c in self._countries})
        for c in self._countries:
            for synonym in c.synonyms:
                self._index[synonym.lower()] = c

    def _load_countries(self) -> List[Country]:
        """Loads country data from a static JSON file."""
        return [
            Country(
                d["label"],
                d["iso_alpha2"],
                d["iso_alpha3"],
                d["iso_numeric"],
                d["synonyms"],
            )
            for d in countries
        ]

    def all(self) -> List[Country]:
        """Returns a list of all countries."""
        return self._countries

    def __iter__(self) -> Iterator[Country]:
        """Allows iteration over all countries."""
        return iter(self._countries)

    def __getitem__(self, key: Union[str, int]) -> Union[Country, None]:
        """Lookup country by ISO Alpha-2, ISO Alpha-3, ISO Numeric, or name (case insensitive, with fuzzy search)."""
        if isinstance(key, int):
            key = str(key)

        key_upper = key.upper()
        key_lower = key.lower()

        if key_upper in self._index:
            return self._index[key_upper]
        if key_lower in self._index:
            return self._index[key_lower]

        # Fuzzy search with rapidfuzz
        country_labels = list(self._index.keys())
        closest_match = process.extractOne(key_lower, country_labels)

        if closest_match and closest_match[1] > 75:  # Threshold for similarity
            return self._index[closest_match[0]]

        raise KeyError(f"Country '{key}' not found.")
